@@ -4,7 +4,7 @@ use strict;
 BEGIN {
   use Exporter ();
   use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-  $VERSION     = 0.3;
+  $VERSION     = 0.1;
   @ISA         = qw (Exporter);
   #Give a hoot don't pollute, do not export more than needed by default
   @EXPORT      = qw ();
@@ -12,7 +12,7 @@ BEGIN {
   %EXPORT_TAGS = ();
 }
 
-use base qw(Class::DBI::Pg );
+use base qw(Class::DBI::Pg Class::DBI::AbstractSearch);
 # it inherits from Class::DBI
 HTTPD::ADS::DBI->set_db('Main', 'dbi:Pg:dbname=wwwads','','',{AutoCommit =>1});
 
@@ -35,7 +35,7 @@ as a part of the HTTPD::ADS system.
 
 This module contains the objects for the database. Each table is its
 own subclass of HTTPD::ADS::DBI. This module and its classes are built on Class::DBI
-
+and Class::DBI::AbstractSearch (to provide support for WHERE clauses)
 
 
 =head1 USAGE
@@ -81,31 +81,29 @@ perl(1). Class::DBI,Class::DBI::Pg,SQL::AbstractSearch
 
 ################################################ subroutine header begin ##
 
-=head2 HTTPD::ADS::Hosts
+=head2 sample_function
 
  Usage     : How to use this function/method
- Purpose   : database table class for hosts 
- Returns   :class/instances for database table
- Argument  : column names are methods in this class 
- Throws    :
- Comments  : 
-           :
+ Purpose   : What it does
+ Returns   : What it returns
+ Argument  : What it wants to know
+ Throws    : Exceptions and other anomolies
+ Comments  : This is a sample subroutine header.
+           : It is polite to include more pod and fewer comments.
 
-See Also   : Class::DBI
+See Also   :
 
 =cut
 
 ################################################## subroutine header end ##
 package HTTPD::ADS::Hosts;
 use base 'HTTPD::ADS::DBI';
-#HTTPD::ADS::Hosts->set_up_table('hosts');
-__PACKAGE__->table('hosts');
-__PACKAGE__->columns(Primary =>'ip');
-__PACKAGE__->columns(All => qw(ip score score_ts));
+HTTPD::ADS::Hosts->set_up_table('hosts');
 
-#package HTTPD::ADS::Arg_strings;
-#use base 'HTTPD::ADS::DBI';
-#HTTPD::ADS::Arg_strings->set_up_table('arg_strings');
+
+package HTTPD::ADS::Arg_strings;
+use base 'HTTPD::ADS::DBI';
+HTTPD::ADS::Arg_strings->set_up_table('arg_strings');
 
 package HTTPD::ADS::Usernames;
 use base 'HTTPD::ADS::DBI';
@@ -114,10 +112,6 @@ use CLASS;
 use Carp;
 my %usernames_cache;
 
-#CLASS->table('usernames');
-#CLASS->columns(Primary =>'userid');
-#CLASS->columns(All => qw (userid username));
-#CLASS->sequence('userid');
 
 sub cached_find_or_create {
   my $self = shift;
@@ -145,11 +139,6 @@ use CLASS;
 use Carp;
 my %request_strings_cache;
 
-#CLASS->table('request_strings');
-#CLASS->columns(Primary => 'requestid');
-#CLASS->columns(All =>qw (requestid request_string));
-#CLASS->sequence('requestid');
-
 
 sub cached_find_or_create  {
   my $self = shift;
@@ -172,53 +161,14 @@ sub cached_find_or_create  {
 package HTTPD::ADS::Eventrecords;
 use base 'HTTPD::ADS::DBI';
 HTTPD::ADS::Eventrecords->set_up_table('eventrecords');
-
-__PACKAGE__->set_sql(count_errors => qq {
-SELECT COUNT(eventid) from eventrecords WHERE (status >= 400 ) AND (ip = ?) AND ( ts >= ?)
-});
-
-sub count_errors {
-  my ($self,@args) = @_;
-#  my $sth = $self->sql_single("COUNT(ip) from eventrecords WHERE (status >=400) AND (ip = ?) AND ( ts >= ?) ");
-#  my $result = $sth->select_val(\@args,['ip','ts']);
- my $Iterator = $self->search_count_errors(@args);
-my $row = $Iterator->next;
-return $$row{count};
-};
-
-
-__PACKAGE__->set_sql(first_event => qq {
-SELECT id from __TABLE__ WHERE (status >= 400 ) AND (ip = ?) AND ( ts >= ?))
-});
 package HTTPD::ADS::Blacklist;
 use base 'HTTPD::ADS::DBI';
 #HTTPD::ADS::Blacklist->set_up_table('blacklist');
 HTTPD::ADS::Blacklist->columns(Primary => qw /ip blocked_at/ );
 HTTPD::ADS::Blacklist->columns(Others => qw /active first_event block_reason unblocked_at unblock_reason/ );
-#HTTPD::ADS::Blacklist->might_have(host => HTTPD::ADS::Hosts =>
-#				  (qw / nic_handle_notified notice_ts open_proxy open_proxy_test_at freq401 last_freq_computed_at/)				 );
-#package HTTPD::ADS::freq401;
-#use base 'HTTPD::ADS::DBI';
-#HTTPD::ADS::freq401->set_up_table('freq401');
-
-package HTTPD::ADS::notice_templates;
-use base 'HTTPD::ADS::DBI';
-#HTTPD::ADS::notice_templates->set_up_table('notice_templates');
-__PACKAGE__->table('notice_templates');
-__PACKAGE__->columns(Primary =>'notice_name');
-__PACKAGE__->columns(All => qw(notice_name template));
-
-package HTTPD::ADS::proxy_tested;
-use base 'HTTPD::ADS::DBI';
-HTTPD::ADS::proxy_tested->set_up_table('proxy_tested');
-
-package HTTPD::ADS::notified;
-use base 'HTTPD::ADS::DBI';
-#HTTPD::ADS::notified->set_up_table('notified');
-__PACKAGE__->table('notified');
-__PACKAGE__->columns(Primary =>'ip');
-__PACKAGE__->columns(All => qw(ip nic_handle_notified notice_ts notice_name));
-
+HTTPD::ADS::Blacklist->might_have(host => HTTPD::ADS::Hosts =>
+				  (qw / nic_handle_notified notice_ts open_proxy open_proxy_test_at freq401 last_freq_computed_at/)
+				 );
 package HTTPD::ADS::Whitelist;
 #use base 'HTTPD::ADS::DBI';
 #HTTPD::ADS::Whitelist->set_up_table('whitelist');
@@ -230,15 +180,10 @@ package HTTPD::ADS::Whitelist;
     $whitelist{$entry}=1;
   }
   ;
-  {
-		     #whitelist the root name servers of the Internet 
-  my ($name,$aliases, $addrtype, $length,@addrs);
   foreach $entry ('A'..'Z') {
-    ($name,$aliases, $addrtype, $length,@addrs) = gethostbyname("$entry.ROOT-SERVERS.NET");
-    last unless defined $addrs[0];#the root servers are assigned in order w/o gaps
-     $whitelist{sprintf "%vd",$addrs[0]} = 1;
-  }  ;
-}
+    $whitelist{gethostbyname("$entry.ROOT-SERVERS.NET")} = 1;
+  }
+  ;		     #whitelist the root name servers of the Internet 
 
   sub retrieve # Class method! named for compatibility with naming of Class::DBI
     {
